summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/libgroupwise/gwfield.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/libgroupwise/gwfield.h')
-rw-r--r--kopete/protocols/groupwise/libgroupwise/gwfield.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kopete/protocols/groupwise/libgroupwise/gwfield.h b/kopete/protocols/groupwise/libgroupwise/gwfield.h
index 0117b3e5..1f8deea2 100644
--- a/kopete/protocols/groupwise/libgroupwise/gwfield.h
+++ b/kopete/protocols/groupwise/libgroupwise/gwfield.h
@@ -22,7 +22,7 @@
#define GWFIELD_H
/* Field types */
-/* Comments: ^1 not used ^2 ignored ^3 apparently only used in _field_to_string for debug */
+/* Comments: ^1 not used ^2 ignored ^3 aptqparently only used in _field_to_string for debug */
/* Otherwise: widely used */
#define NMFIELD_TYPE_INVALID 0
/* ^1 */
@@ -122,14 +122,14 @@
// GW7
#define NM_A_FA_CUSTOM_STATUSES "NM_A_FA_CUSTOM_STATUSES"
#define NM_A_FA_STATUS "NM_A_FA_STATUS"
-#define NM_A_UD_QUERY_COUNT "NM_A_UD_QUERY_COUNT"
+#define NM_A_UD_TQUERY_COUNT "NM_A_UD_TQUERY_COUNT"
#define NM_A_FA_CHAT "NM_A_FA_CHAT"
#define NM_A_DISPLAY_NAME "nnmDisplayName"
#define NM_A_CHAT_OWNER_DN "nnmChatOwnerDN"
#define NM_A_UD_PARTICIPANTS "NM_A_UD_PARTICIPANTS"
#define NM_A_DESCRIPTION "nnmDescription"
#define NM_A_DISCLAIMER "nnmDisclaimer"
-#define NM_A_QUERY "nnmQuery"
+#define NM_A_TQUERY "nnmQuery"
#define NM_A_ARCHIVE "nnmArchive"
#define NM_A_MAX_USERS "nnmMaxUsers"
#define NM_A_SZ_TOPIC "NM_A_SZ_TOPIC"
@@ -167,18 +167,18 @@ namespace Field
{
public:
FieldBase() {}
- FieldBase( TQCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type );
+ FieldBase( TQCString tag, TQ_UINT8 method, TQ_UINT8 flags, TQ_UINT8 type );
virtual ~FieldBase() {}
TQCString tag() const;
- Q_UINT8 method() const;
- Q_UINT8 flags() const;
- Q_UINT8 type() const;
- void setFlags( const Q_UINT8 flags );
+ TQ_UINT8 method() const;
+ TQ_UINT8 flags() const;
+ TQ_UINT8 type() const;
+ void setFlags( const TQ_UINT8 flags );
protected:
TQCString m_tag;
- Q_UINT8 m_method;
- Q_UINT8 m_flags;
- Q_UINT8 m_type; // doch needed
+ TQ_UINT8 m_method;
+ TQ_UINT8 m_flags;
+ TQ_UINT8 m_type; // doch needed
};
typedef TQValueListIterator<FieldBase *> FieldListIterator;
@@ -194,18 +194,18 @@ namespace Field
*/
virtual ~FieldList();
/**
* Locate the first occurrence of a given field in the list. Same semantics as TQValueList::find().
* @param tag The tag name of the field to search for.
* @return An iterator pointing to the first occurrence found, or end() if none was found.
*/
- FieldListIterator find( TQCString tag );
+ FieldListIterator tqfind( TQCString tag );
/**
* Locate the first occurrence of a given field in the list, starting at the supplied iterator
* @param tag The tag name of the field to search for.
* @param it An iterator within the list, to start searching from.
* @return An iterator pointing to the first occurrence found, or end() if none was found.
*/
- FieldListIterator find( FieldListIterator &it, TQCString tag );
+ FieldListIterator tqfind( FieldListIterator &it, TQCString tag );
/**
* Get the index of the first occurrence of tag, or -1 if not found
*/
@@ -242,11 +242,11 @@ namespace Field
/**
* Single field constructor
*/
- SingleField( TQCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type, TQVariant value );
+ SingleField( TQCString tag, TQ_UINT8 method, TQ_UINT8 flags, TQ_UINT8 type, TQVariant value );
/**
* Convenience constructor for NMFIELD_METHOD_VALID fields
*/
- SingleField( TQCString tag, Q_UINT8 flags, Q_UINT8 type, TQVariant value );
+ SingleField( TQCString tag, TQ_UINT8 flags, TQ_UINT8 type, TQVariant value );
~SingleField();
void setValue( const TQVariant v );
TQVariant value() const;
@@ -261,8 +261,8 @@ namespace Field
class MultiField : public FieldBase
{
public:
- MultiField( TQCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type );
- MultiField( TQCString tag, Q_UINT8 method, Q_UINT8 flags, Q_UINT8 type, FieldList fields );
+ MultiField( TQCString tag, TQ_UINT8 method, TQ_UINT8 flags, TQ_UINT8 type );
+ MultiField( TQCString tag, TQ_UINT8 method, TQ_UINT8 flags, TQ_UINT8 type, FieldList fields );
~MultiField();
FieldList fields() const;
void setFields( FieldList );
@@ -194,18 +194,18 @@ namespace Field
virtual ~FieldList();
/**
- * Locate the first occurrence of a given field in the list. Same semantics as TQValueList::find().
+ * Locate the first occurrence of a given field in the list. Same semantics as TQValueList::tqfind().
* @param tag The tag name of the field to search for.
* @return An iterator pointing to the first occurrence found, or end() if none was found.